@@ -16,12 +16,10 @@ class PasswordField(CharField):
         """
         """
 
-        # See if the password has been hashed
-        if '$' in self.text:
-            return
-
-        salt = hasher.salt()
-        self.text = '%s' % ( hasher.encode(password=self.text, salt=salt, iterations=12000) )
+        # Check if the password is not already hashed
+        if not '$' in self.text:
+            salt = hasher.salt()
+            self.text = '%s' % ( hasher.encode(password=self.text, salt=salt, iterations=12000) )
 
     def verify(self, password):
         hashed_password = self.text
